@@ -344,6 +344,12 @@ class TrajParser(TextParser):
             return len(self.get_positions(idx))
         return n_atoms[idx]
 
+    def get_step(self, idx):
+        step = self.get('time_step')
+        if step is None:
+            return
+        return step[idx]
+
 
 class XYZTrajParser(TrajParser):
     def __init__(self):
@@ -626,7 +632,7 @@ class LammpsParser:
             'e_tail': 'van der Waals long range', 'kineng': 'kinetic', 'poteng': 'potential'}
         self._frame_rate = None
         # max cumulative number of atoms for all parsed trajectories to calculate sampling rate
-        self._cum_max_atoms = 1000000
+        self._cum_max_atoms = 2500000
 
     @property
     def frame_rate(self):
@@ -648,6 +654,9 @@ class LammpsParser:
         return time_step
 
     def parse_thermodynamic_data(self):
+        sec_run = self.archive.run[-1]
+        sec_system = sec_run.system
+
         time_step = self.get_time_step()
         thermo_data = self.log_parser.get_thermodynamic_data()
         if thermo_data is None:
@@ -655,45 +664,44 @@ class LammpsParser:
         if not thermo_data:
             return
 
-        sec_run = self.archive.run[-1]
-        sec_sccs = sec_run.calculation
+        calculation_steps = thermo_data.get('Step')
+        calculation_steps = [int(val) if val is not None else None for val in calculation_steps]
 
-        n_thermo = len(thermo_data.get('Step', []))
-        create_scc = True
-        if sec_sccs:
-            if len(sec_sccs) != n_thermo:
-                self.logger.warning(
-                    '''Mismatch in number of calculations and number of property
-                    evaluations!, will create new sections''',
-                    data=dict(n_calculations=len(sec_sccs), n_evaluations=n_thermo))
+        step_map = {}
+        for i_calc, calculation_step in enumerate(calculation_steps):
+            system_index = self._system_step_map.pop(calculation_steps[i_calc], None)
+            step_map[calculation_step] = {'system_index': system_index, 'calculation_index': i_calc}
+        for step, i_sys in self._system_step_map.items():
+            step_map[step] = {'system_index': i_sys, 'calculation_index': None}
 
-            else:
-                create_scc = False
-        for n in range(n_thermo):
+        for step in sorted(step_map):
+            sec_scc = sec_run.m_create(Calculation)
+            sec_scc.step = step
+            sec_scc.time = sec_scc.step * time_step  # TODO Physical times should not be stored for GeometryOpt
+            sec_scc.method_ref = sec_run.method[-1] if sec_run.method else None
 
-            if create_scc:
-                sec_scc = sec_run.m_create(Calculation)
-            else:
-                sec_scc = sec_sccs[n]
+            system_index = step_map[step]['system_index']
+            if system_index is not None:
+                sec_scc.forces = Forces(total=ForcesEntry(value=self.traj_parsers.eval('get_forces', system_index)))
+                sec_scc.system_ref = sec_system[system_index]
 
-            sec_energy = sec_scc.m_create(Energy)
-            for key, val in thermo_data.items():
-                key = key.lower()
-                if key in self._energy_mapping:
-                    sec_energy.contributions.append(
-                        EnergyEntry(kind=self._energy_mapping[key], value=val[n]))
-                elif key == 'toteng':
-                    sec_energy.current = EnergyEntry(value=val[n])
-                    sec_energy.total = EnergyEntry(value=val[n])
-                elif key == 'press':
-                    sec_scc.pressure = val[n]
-                elif key == 'temp':
-                    sec_scc.temperature = val[n]
-                elif key == 'step':
-                    sec_scc.step = int(val[n])
-                    sec_scc.time = sec_scc.step * time_step
-                elif key == 'cpu':
-                    sec_scc.time_calculation = float(val[n])
+            calculation_index = step_map[step]['calculation_index']
+            if calculation_index is not None:
+                sec_energy = sec_scc.m_create(Energy)
+                for key, val in thermo_data.items():
+                    key = key.lower()
+                    if key in self._energy_mapping:
+                        sec_energy.contributions.append(
+                            EnergyEntry(kind=self._energy_mapping[key], value=val[calculation_index]))
+                    elif key == 'toteng':
+                        sec_energy.current = EnergyEntry(value=val[calculation_index])
+                        sec_energy.total = EnergyEntry(value=val[calculation_index])
+                    elif key == 'press':
+                        sec_scc.pressure = val[calculation_index]
+                    elif key == 'temp':
+                        sec_scc.temperature = val[calculation_index]
+                    elif key == 'cpu':
+                        sec_scc.time_calculation = float(val[calculation_index])
 
     def parse_workflow(self):
         sec_workflow = self.archive.m_create(Workflow)
@@ -1078,11 +1086,17 @@ class LammpsParser:
             formula = ''.join([f'{name}({count})' for name, count in zip(*children_count_tup)])
             return formula
 
+        self._system_step_map = {}
         for i in range(n_frames):
             if (i % self.frame_rate) > 0:
                 continue
 
             sec_system = sec_run.m_create(System)
+            step = self.traj_parsers.eval('get_step', i)  # TODO Physical times should not be stored for GeometryOpt
+            step = int(step) if step is not None else None
+            if step is not None:
+                self._system_step_map[step] = len(self._system_step_map)
+
             sec_atoms = sec_system.m_create(Atoms)
             sec_atoms.n_atoms = self.traj_parsers.eval('get_n_atoms', i)
             lattice_vectors = self.traj_parsers.eval('get_lattice_vectors', i)
@@ -1098,11 +1112,6 @@ class LammpsParser:
             if velocities is not None:
                 sec_system.atoms.velocities = apply_unit(velocities, 'velocity')
 
-            forces = self.traj_parsers.eval('get_forces', i)
-            if forces is not None:
-                sec_scc = sec_run.m_create(Calculation)
-                sec_scc.forces = Forces(total=ForcesEntry(value=apply_unit(forces, 'force')))
-
         # parse atomsgroup (moltypes --> molecules --> residues)
         atoms_info = self._mdanalysistraj_parser.get('atoms_info', None)
         if atoms_info is None:
