@@ -27,7 +27,7 @@ from nomad.parsing.file_parser import TextParser, Quantity, DataTextParser
 from nomad.datamodel.metainfo.simulation.run import Run, Program, TimeRun
 from nomad.datamodel.metainfo.simulation.method import (
     Electronic, Method, XCFunctional, Functional, HubbardKanamoriModel, AtomParameters, DFT,
-    BasisSet, GW as GWMethod, KMesh
+    BasisSet, GW as GWMethod, KMesh, FreqMesh
 )
 from nomad.datamodel.metainfo.simulation.system import (
     System, Atoms
@@ -37,17 +37,17 @@ from nomad.datamodel.metainfo.simulation.calculation import (
     ScfIteration, Energy, EnergyEntry, Stress, StressEntry, Thermodynamics,
     Forces, ForcesEntry
 )
-from nomad.datamodel.metainfo.workflow import Workflow, Task, GW as GWWorkflow
-from nomad.datamodel.metainfo.workflow2 import TaskReference, Link
+from nomad.datamodel.metainfo.workflow import Workflow
 from nomad.datamodel.metainfo.simulation.workflow import (
     SinglePoint as SinglePoint2, GeometryOptimization as GeometryOptimization2,
-    MolecularDynamics as MolecularDynamics2, GW as GW2, GWResults)
+    MolecularDynamics as MolecularDynamics2)
 
 from .metainfo.fhi_aims import Run as xsection_run, Method as xsection_method,\
     x_fhi_aims_section_parallel_task_assignement, x_fhi_aims_section_parallel_tasks,\
     x_fhi_aims_section_controlIn_basis_set, x_fhi_aims_section_controlIn_basis_func,\
     x_fhi_aims_section_controlInOut_atom_species, x_fhi_aims_section_controlInOut_basis_func,\
     x_fhi_aims_section_vdW_TS
+from ..utils import BeyondDFTWorkflowsParser
 
 
 re_float = r'[-+]?\d+\.\d*(?:[Ee][-+]\d+)?'
@@ -560,6 +560,8 @@ class FHIAimsOutParser(TextParser):
                 'gw_flag', rf'{re_n}\s*qpe_calc\s*([\w]+)', repeats=False),
             Quantity(
                 'gw_flag', rf'{re_n}\s*sc_self_energy\s*([\w]+)', repeats=False),
+            Quantity(
+                'anacon_type', rf'{re_n}\s*anacon_type\s*(\d+)', repeats=False),
             Quantity(
                 'gw_analytical_continuation',
                 rf'{re_n} (?:Using)*\s*([\w\-\s]+) for analytical continuation',
@@ -579,6 +581,10 @@ class FHIAimsOutParser(TextParser):
             Quantity(
                 'frozen_core', rf'{re_n}\s*frozen_core_scf\s*(\d+)', repeats=False,
                 dtype=int),
+            Quantity(
+                'n_states_gw',
+                r'\|\s*Number of Kohn-Sham states \(occupied \+ empty\)\s*\:\s*(\d+)',
+                repeats=False),
             Quantity(
                 'gw_self_consistency', r'GW Total Energy Calculation([\s\S]+?)\-{5}',
                 repeats=True, str_operation=str_to_gw_scf, convert=False),
@@ -623,14 +629,14 @@ class FHIAimsOutParser(TextParser):
         return self.get('array_size_parameters', {}).get('Number of spin channels', 1)
 
 
-class FHIAimsParser:
+class FHIAimsParser(BeyondDFTWorkflowsParser):
     def __init__(self):
         self.out_parser = FHIAimsOutParser()
         self.control_parser = FHIAimsControlParser()
         self.dos_parser = DataTextParser()
         self.bandstructure_parser = DataTextParser()
-        self._child_archives = {}
         self._calculation_type = 'dft'
+        self._child_archives = {}
 
         self._xc_map = {
             'Perdew-Wang parametrisation of Ceperley-Alder LDA': [
@@ -748,11 +754,7 @@ class FHIAimsParser:
             'scgw': 'scGW'
         }
 
-        self._gw_analytical_continuation_map = {
-            'pade': 'pade',
-            'pole': 'multi-pole',
-            'countour': 'CD'
-        }
+        self.gw_analytical_continuation = ['multi_pole', 'pade']
 
         self._gw_qp_energies_map = {
             'occ_num': 'occupations',
@@ -856,26 +858,23 @@ class FHIAimsParser:
         # GW method
         sec_method = sec_run.m_create(Method)
         sec_gw = sec_method.m_create(GWMethod)
+        # Type
         sec_gw.type = self._gw_flag_map.get(self.out_parser.get('gw_flag'), None)
-
-        # TODO check this with FHIaims GW developers
-        sec_k_mesh = sec_method.m_create(KMesh)
+        # Q mesh
+        sec_k_mesh = sec_gw.m_create(KMesh)
         sec_k_mesh.grid = self.out_parser.get('k_grid', [1, 1, 1])
-        sec_gw.q_grid = sec_k_mesh
-        if self.out_parser.get('frozen_core', None) is not None:
-            sec_gw.core_treatment = 'fc'
-        sec_gw.dielectric_function_treatment = 'rpa'
-
-        if self.out_parser.get('gw_analytical_continuation') is not None:
-            sec_gw.self_energy_analytical_continuation = self._gw_analytical_continuation_map.get([
-                i for i in self.out_parser.get('gw_analytical_continuation') for x in self._gw_analytical_continuation_map.keys() if i == x][0])
-        else:
-            self.logger.warn(
-                'Analytical continuation approximation for the GW self-energy not found')
-        sec_gw.n_frequencies = self.out_parser.get('n_freq', 100)
+        # Analytical continuation
+        sec_gw.analytical_continuation = self.gw_analytical_continuation[
+            self.out_parser.get('anacon_type', 1)]
+        # Frequency grid
+        sec_freq_grid = sec_gw.m_create(FreqMesh)
+        sec_freq_grid.type = self.out_parser.get('freq_grid_type')
+        sec_freq_grid.n_points = self.out_parser.get('n_freq', 100)
         frequency_data = self.out_parser.get('frequency_data', None)
         if frequency_data is not None:
-            sec_gw.frequency_values = np.array(frequency_data)[:, 1] * ureg.hartree
+            sec_freq_grid.values = np.array(frequency_data)[:, 1] * ureg.hartree
+        # Other parameters
+        sec_gw.n_states_self_energy = self.out_parser.get('n_states_gw')
 
         # GW calculation
         sec_scc = sec_run.m_create(Calculation)
@@ -928,85 +927,6 @@ class FHIAimsParser:
                 val = gw_eigenvalues[key] if key == 'occ_num' else gw_eigenvalues[key] * ureg.eV
                 setattr(sec_eigs_gw, name, np.reshape(val, (1, 1, len(val))))
 
-    def parse_gw_workflow(self, gw_archive, gw_workflow_archive):
-        sec_run = gw_workflow_archive.m_create(Run)
-        sec_run.program = self.archive.run[-1].program
-        setattr(sec_run, 'system', self.archive.run[-1].system)
-
-        sec_workflow = gw_workflow_archive.m_create(Workflow)
-        sec_workflow.type = 'GW'
-        sec_workflow.workflows_ref = [self.archive.workflow[0], gw_archive.workflow[0]]
-
-        # Tasks linking dft and gw
-        sec_workflow.task = [
-            Task(
-                input_workflow=sec_workflow, output_workflow=self.archive.workflow[0],
-                description='DFT calculation performed in an input structure.'),
-            Task(
-                input_workflow=self.archive.workflow[0], output_workflow=gw_archive.workflow[0],
-                description='GW calculation performed from input DFT calculation.'),
-            Task(
-                input_workflow=gw_archive.workflow[0], output_workflow=sec_workflow,
-                description='Comparison between DFT and GW.')
-        ]
-
-        # Include DFT and GW band structures and DOS (if present) for comparison.
-        def extract_section(source, path):
-            path_segments = path.split('/', 1)
-            try:
-                value = getattr(source, path_segments[0])
-                value = value[-1] if isinstance(value, list) else value
-            except Exception:
-                return
-
-            if len(path_segments) == 1:
-                return value
-            else:
-                return extract_section(value, path_segments[1])
-
-        sec_gw = sec_workflow.m_create(GWWorkflow)
-        dos_dft = extract_section(self.archive, 'run/calculation/dos_electronic')
-        dos_gw = extract_section(gw_archive, 'run/calculation/dos_electronic')
-        bs_dft = extract_section(self.archive, 'run/calculation/band_structure_electronic')
-        bs_gw = extract_section(gw_archive, 'run/calculation/band_structure_electronic')
-        sec_gw.dos_dft = dos_dft
-        sec_gw.dos_gw = dos_gw
-        sec_gw.band_structure_dft = bs_dft
-        sec_gw.band_structure_gw = bs_gw
-
-        workflow = GW2(results=GWResults())
-        workflow.results.dos_dft = dos_dft
-        workflow.results.dos_gw = dos_gw
-        workflow.results.band_structure_dft = bs_dft
-        workflow.results.band_structure_gw = bs_gw
-
-        input_structure = extract_section(self.archive, 'run/system')
-        if input_structure:
-            workflow.inputs = [Link(name='Input structure', section=input_structure)]
-        output_calculation = extract_section(gw_archive, 'run/calculation')
-        if output_calculation:
-            workflow.outputs = [Link(name='Output calculation', section=output_calculation)]
-
-        # output of dft and input for gw
-        input_calculation = extract_section(self.archive, 'run/calculation')
-        if self.archive.workflow2:
-            task = TaskReference(task=self.archive.workflow2)
-            if input_structure:
-                task.inputs = [Link(name='Input structure', section=input_structure)]
-            if input_calculation:
-                task.outputs = [Link(name='Output calculation', section=input_calculation)]
-            workflow.tasks.append(task)
-
-        if gw_archive.workflow2:
-            task = TaskReference(task=gw_archive.workflow2)
-            if input_calculation:
-                task.inputs = [Link(name='Input calculation', section=input_calculation)]
-            if output_calculation:
-                task.outputs = [Link(name='Output calculation', section=output_calculation)]
-            workflow.tasks.append(task)
-
-        gw_workflow_archive.workflow2 = workflow
-
     def parse_system(self, section):
         sec_run = self.archive.run[-1]
 
@@ -1699,4 +1619,7 @@ class FHIAimsParser:
 
             # GW workflow
             gw_workflow_archive = self._child_archives.get('GW_workflow')
-            self.parse_gw_workflow(gw_archive, gw_workflow_archive)
+            try:
+                self.parse_gw_workflow(gw_archive, gw_workflow_archive)
+            except Exception:
+                self.logger.error('Error parsing the automatic GW workflow')
