@@ -349,12 +349,12 @@ class GamessParser:
             'DLDF': [{'name': 'MGGA_XC_DLDF'}],
             'M05': [{'name': 'HYB_MGGA_XC_M05'}],
             'M05-2X': [{'name': 'HYB_MGGA_XC_M05_2X'}],
-            'M06': [{'name': 'HYB_MGGA_XC_M06'}],
+            'M06': [{'name': 'MGGA_C_M06'}, {'name': 'HYB_MGGA_X_M06'}],
             'M06-L': [{'name': 'MGGA_C_M06_L'}, {'name': 'MGGA_X_M06_L'}],
-            'M06-2X': [{'name': 'HYB_MGGA_XC_M06_2X'}],
-            'M06-HF': [{'name': 'HYB_MGGA_XC_M06_HF'}],
-            'M08-HX': [{'name': 'HYB_MGGA_XC_M08_HX'}],
-            'M08-SO': [{'name': 'HYB_MGGA_XC_M08_SO'}],
+            'M06-2X': [{'name': 'MGGA_C_M06_2X'}, {'name': 'HYB_MGGA_X_M06_2X'}],
+            'M06-HF': [{'name': 'MGGA_C_M06_HF'}, {'name': 'HYB_MGGA_X_M06_HF'}],
+            'M08-HX': [{'name': 'MGGA_C_M08_HX'}, {'name': 'HYB_MGGA_X_M08_HX'}],
+            'M08-SO': [{'name': 'MGGA_C_M08_SO'}, {'name': 'HYB_MGGA_X_M08_SO'}],
             'M11-L': [{'name': 'MGGA_C_M11_L'}, {'name': 'MGGA_X_M11_L'}],
             'M11': [{'name': 'MGGA_C_M11_L'}, {'name': 'MGGA_X_M11'}],
             'RHF': [{'name': 'RHF_X'}],
