@@ -23,6 +23,7 @@ import h5py
 import re
 
 from nomad.units import ureg
+from nomad.datamodel.metainfo.simulation.workflow import SinglePoint
 from nomad.datamodel.metainfo.simulation.run import Run, Program
 from nomad.datamodel.metainfo.simulation.calculation import (
     Calculation, ScfIteration, Energy, GreensFunctions
@@ -392,3 +393,5 @@ class SolidDMFTParser:
         # Workflow section
         sec_workflow = self.archive.m_create(Workflow)
         sec_workflow.type = 'single_point'
+        workflow = SinglePoint()
+        self.archive.workflow2 = workflow
