@@ -17,9 +17,9 @@
 #
 
 import click
-
 from nomad import config
 from .admin import admin
+from nomad import utils
 
 
 @admin.group(help='Run a nomad service locally (outside docker).')
@@ -27,6 +27,11 @@ def run():
     pass
 
 
+@run.command(help='Run the jupyter hub.')
+def hub():
+    run_hub()
+
+
 @run.command(help='Run the nomad development worker.')
 def worker():
     run_worker()
@@ -34,9 +39,7 @@ def worker():
 
 @run.command(help='Run the nomad development app with all apis.')
 @click.option('--debug', help='Does run app in debug.', is_flag=True)
-@click.option('--with-chaos', type=int, default=0, help='Enable a certain percentage of chaos.')
-def app(debug: bool, with_chaos: int):
-    config.services.api_chaos = with_chaos
+def app(debug: bool):
     run_app(debug=debug)
 
 
@@ -57,6 +60,38 @@ def run_worker():
     processing.app.worker_main(['worker', '--loglevel=INFO', '-Q', 'celery'])
 
 
+def run_hub():
+    from jupyterhub.app import main
+    import sys
+    import os
+    import subprocess
+
+    if 'JUPYTERHUB_CRYPT_KEY' not in os.environ:
+        crypt_key = config.north.jupyterhub_crypt_key
+        if crypt_key is None:
+            crypt_key = subprocess.check_output('openssl rand -hex 32'.split(' ')).decode().strip('\n')
+        os.environ['JUPYTERHUB_CRYPT_KEY'] = crypt_key
+
+    config.meta.service = 'hub'
+    sys.exit(main(argv=['-f', 'nomad/jupyterhub_config.py', '--Application.log_level=INFO']))
+
+
+def task_app():
+    logger = utils.get_logger('app')
+    try:
+        run_app()
+    except Exception as error:
+        logger.exception(error)
+
+
+def task_worker():
+    logger = utils.get_logger('worker')
+    try:
+        run_worker()
+    except Exception as error:
+        logger.exception(error)
+
+
 @run.command(help='Run both app and worker.')
 def appworker():
     from concurrent import futures as concurrent_futures
@@ -64,5 +99,5 @@ def appworker():
 
     executor = concurrent_futures.ProcessPoolExecutor(2)
     loop = asyncio.get_event_loop()
-    loop.run_in_executor(executor, run_app)
-    loop.run_in_executor(executor, run_worker)
+    loop.run_in_executor(executor, task_app)
+    loop.run_in_executor(executor, task_worker)
