@@ -17,10 +17,6 @@
 #
 
 import click
-import json
-import datetime
-
-from nomad import infrastructure, datamodel, utils
 
 from .admin import admin
 
@@ -33,6 +29,11 @@ def users():
 @users.command(help='Import users to keycloak from a JSON file.', name='import')
 @click.argument('PATH_TO_USERS_FILE', type=str, nargs=1)
 def import_command(path_to_users_file):
+    import json
+    import datetime
+
+    from nomad import infrastructure, datamodel, utils
+
     with open(path_to_users_file, 'rt') as f:
         users = json.load(f)
 
@@ -43,7 +44,7 @@ def import_command(path_to_users_file):
             password = user_dict.pop('password')
             user_dict['created'] = datetime.datetime.fromtimestamp(user_dict['created'] / 1000)
             user = datamodel.User(**user_dict)
-            infrastructure.keycloak.add_user(user, bcrypt_password=password, invite=False)
+            infrastructure.user_management.add_user(user, bcrypt_password=password, invite=False)
             print('Imported %s' % user.name)
         except Exception as e:
             logger.error('could not import user', exc_info=e)
