@@ -138,7 +138,7 @@ class Context(MetainfoContext):
         ''' Loads the archive for the given identification. '''
         raise NotImplementedError()
 
-    def load_raw_file(self, path: str, upload_id: str, installation_url: str) -> MSection:
+    def load_raw_file(self, path: str, upload_id: str, installation_url: str, url: str = None) -> MSection:
         ''' Loads a raw file based on the given upload and path. Interpret as metainfo data. '''
         raise NotImplementedError()
 
@@ -190,7 +190,7 @@ class Context(MetainfoContext):
         if kind == 'archive':
             return self.load_archive(entry_id_or_mainfile, upload_id, installation_url)
 
-        return self.load_raw_file(entry_id_or_mainfile, upload_id, installation_url)
+        return self.load_raw_file(entry_id_or_mainfile, upload_id, installation_url, url)
 
     def resolve_archive_url(self, url: str) -> MSection:
         if url not in self.archives:
@@ -239,11 +239,21 @@ class ServerContext(Context):
         try:
             archive_dict = upload_files.read_archive(entry_id)[entry_id].to_dict()
         except KeyError:
-            raise MetainfoReferenceError(f'archive does not exist {entry_id}')
+            if upload_id != self.upload_id:
+                raise MetainfoReferenceError(f'Referencing another Upload is not allowed.')
+            from nomad.processing import Entry
+            if entry := Entry.objects(entry_id=entry_id).first():
+                return self.load_raw_file(entry.mainfile, upload_id, installation_url)
+            raise MetainfoReferenceError(f'Could not load {entry_id}.')
 
-        return EntryArchive.m_from_dict(archive_dict, m_context=self)
+        context = self
+        if upload_id != self.upload_id:
+            from nomad.processing import Upload
+            context = ServerContext(Upload(upload_id=upload_id))
 
-    def load_raw_file(self, path: str, upload_id: str, installation_url: str) -> EntryArchive:
+        return EntryArchive.m_from_dict(archive_dict, m_context=context)
+
+    def load_raw_file(self, path: str, upload_id: str, installation_url: str, url: str = None) -> EntryArchive:
         upload_files = self._get_upload_files(upload_id, installation_url)
 
         try:
@@ -257,8 +267,12 @@ class ServerContext(Context):
                     mainfile=path,
                     entry_id=utils.generate_entry_id(upload_id, path)))
             from nomad.parsing.parser import ArchiveParser
+            parser = ArchiveParser()
             with upload_files.raw_file(path, 'rt') as f:
-                ArchiveParser().parse_file(path, f, archive)
+                parser.parse_file(path, f, archive)
+            if url:
+                self.cache_archive(url, archive)
+            parser.validate_defintions(archive)
             return archive
         except Exception:
             raise MetainfoReferenceError(f'Could not load {path}.')
@@ -323,6 +337,7 @@ class ClientContext(Context):
         username: str = None, password: str = None, auth=None
     ):
         super().__init__(config.client.url + '/v1' if installation_url is None else installation_url)
+        self._installation_url = installation_url
         self.local_dir = local_dir
         if auth:
             self._auth = auth
@@ -347,9 +362,13 @@ class ClientContext(Context):
         if response.status_code != 200:
             raise MetainfoReferenceError(f'cannot retrieve archive {entry_id} from {installation_url}')
 
-        return EntryArchive.m_from_dict(response.json()['data']['archive'], m_context=self)
+        context = self
+        if upload_id != self.upload_id:
+            context = ClientContext(installation_url=self._installation_url, local_dir=self.local_dir, upload_id=upload_id, auth=self._auth)
 
-    def load_raw_file(self, path: str, upload_id: str, installation_url: str) -> MSection:
+        return EntryArchive.m_from_dict(response.json()['data']['archive'], m_context=context)
+
+    def load_raw_file(self, path: str, upload_id: str, installation_url: str, url: str = None) -> MSection:
         # TODO currently upload_id might be None
         if upload_id is None:
             # try to find a local file, useful when the context is used for local parsing
