@@ -16,11 +16,13 @@
 # limitations under the License.
 #
 
-from typing import List, Any, Union, Dict
+from typing import List, Any, Union, Dict, Optional
 from enum import Enum
 from pydantic import Field, validator
 import re
 
+from pydantic.main import BaseModel
+
 from nomad.utils import strip
 from nomad.metainfo import AnnotationModel, MEnum, MTypes, Datetime, Reference, Quantity
 
@@ -81,6 +83,36 @@ valid_eln_components = {
 }
 
 
+class Filter(BaseModel):
+    ''' A filter defined by an include list or and exclude list of the quantities or subsections. '''
+
+    include: Optional[List[str]] = Field(
+        None, description=strip('''
+            The list of quantity or subsection names to be included.
+        '''))
+    exclude: Optional[List[str]] = Field(
+        None, description=strip('''
+            The list of quantity or subsection names to be excluded.
+        '''))
+
+
+class SectionProperties(BaseModel):
+    ''' A filter defined by an include list or and exclude list of the quantities and subsections. '''
+
+    visible: Optional[Filter] = Field(
+        1, description=strip('''
+            Defines the visible quantities and subsections.
+        '''))
+    editable: Optional[Filter] = Field(
+        None, description=strip('''
+            Defines the editable quantities and subsections.
+        '''))
+    order: Optional[List[str]] = Field(
+        None, description=strip('''
+            To customize the order of the quantities and subsections.
+        '''))
+
+
 class ELNAnnotation(AnnotationModel):
     '''
     These annotations control how data can be entered and edited.
@@ -107,7 +139,7 @@ class ELNAnnotation(AnnotationModel):
     with different parameters; see below.
 
     The UI gives an overview about all ELN edit annotations and components
-    [here]({{ nomad_url() }}/../gui/dev/editquantity).
+    [here](https://nomad-lab.eu/prod/v1/staging/gui/dev/editQuantity).
     '''
 
     component: ELNComponentEnum = Field(None, description='''
@@ -163,10 +195,11 @@ class ELNAnnotation(AnnotationModel):
     ''')
 
     hide: List[str] = Field(None, description='''
+        The annotation "hide" is deprecated. Use "visible" key of "properties" annotation instead.
         Allows you to hide certain quantities from a section editor. Give a list
         of quantity names. Quantities must exist in the section that this annotation
         is added to. Can only be used in section annotations.
-    ''')
+    ''', deprecated=True)
 
     overview: bool = Field(None, description='''
         Shows the annotation section on the entry's overview page. Can only be used on
@@ -177,6 +210,14 @@ class ELNAnnotation(AnnotationModel):
         section and its editor.
     ''')
 
+    properties: SectionProperties = Field(None, description='''
+        The value to customize the quantities and sub sections of the annotation section.
+        The supported keys:
+        `visible`: To determine the visible quantities and sub sections by their names<br/>
+        `editable`: To render things visible but not editable, e.g. in inheritance situations<br/>
+        `order`: # To order things, properties listed in that order first, then the rest<br/>
+    ''')
+
     class Config:
         validate_assignment = True
 
@@ -285,6 +326,8 @@ class BrowserAnnotation(AnnotationModel):
 class TabularMode(str, Enum):
     row = 'row'
     column = 'column'
+    root = 'root'
+    entry = 'entry'
 
 
 class TabularParserAnnotation(AnnotationModel):
@@ -311,10 +354,12 @@ class TabularParserAnnotation(AnnotationModel):
     ''')
     separator: str = Field(None, description='An alias for `sep`')
     mode: TabularMode = Field(TabularMode.column, description='''
-        Either `column` or `row`. With `column` the whole column is mapped into a quantity
+        Either `column`, `row`, `entry` or `root`. With `column` the whole column is mapped into a quantity
         (needs to be a list).
         With `row` each row (and its cells) are mapped into instances of a repeating
         sub section, where each section represents a row (quantities need to be scalars).
+        With `entry` new entry is created and populated from each row (and its cells) where
+        all quantities should remain to be scalars.
         Has to be used to annotate the quantity that
         holds the path to the `.csv` or excel file.
     ''')
@@ -325,18 +370,6 @@ class TabularParserAnnotation(AnnotationModel):
         Has to be used to annotate the quantity that
         holds the path to the `.csv` or excel file.
     ''')
-    path_to_data_file: str = Field(None, description='''
-        A string indicating if a data_file name (i.e. a csv or xls file)
-        should be retrieved from the base class. Default value is set to `None`.
-    ''')
-
-    @validator('path_to_data_file')
-    def validate_data_file_references(cls, value):  # pylint: disable=no-self-argument
-        if not value:
-            value = value if isinstance(value, str) else str(value)
-            assert re.match(r'^#data/(\w+/)*\w+$', value), f'{value} is not a valid data_file reference.'
-
-        return value
 
 
 class TabularAnnotation(AnnotationModel):
@@ -388,6 +421,9 @@ class PlotAnnotation(AnnotationModel):
     "sub_section_name/2/parameter_name" or with a slice notation `start:stop` where
     negative values index from the end of the array, e.g.
     "sub_section_name/1:-5/parameter_name".
+
+    The interactive examples of the plot annotations can be found
+    [here](https://nomad-lab.eu/prod/v1/staging/gui/dev/plot).
     '''
 
     def __init__(self, *args, **kwargs):
