@@ -20,7 +20,7 @@ import numpy as np            # pylint: disable=unused-import
 import typing                 # pylint: disable=unused-import
 from nomad.metainfo import (  # pylint: disable=unused-import
     MSection, MCategory, Category, Package, Quantity, Section, SubSection, SectionProxy,
-    Reference, MEnum, derived)
+    Reference, MEnum, derived, HDF5Reference)
 from nomad.datamodel.metainfo.simulation.system import System, AtomsGroup
 from nomad.datamodel.metainfo.simulation.method import Method, HoppingMatrix
 from nomad.datamodel.data import ArchiveSection
@@ -1463,15 +1463,30 @@ class Density(Volumetric):
         Values of the potential evaluated at each grid point.
         ''')
 
+    # TODO rename this to value or restructure metainfo def for densities and perhaps
+    # rename density_charge to charge_density if no other densities are to be added.
+    value_hdf5 = Quantity(
+        type=HDF5Reference,
+        shape=[],
+        description='''
+        Specifies the HDF5 file and the path to the value in the file .
+        ''')
 
-class ExcitedStates(MSection):
+
+class Spectra(MSection):
     '''
     Excited states properties.
     '''
 
     m_def = Section(validate=False)
 
-    n_excited_states = Quantity(
+    type = Quantity(
+        type=str,
+        description='''
+        A string identifier for the type of spectrum: XAS, RIXS, XES, ARPES, etc.
+        ''')
+
+    n_energies = Quantity(
         type=int,
         shape=[],
         description='''
@@ -1479,24 +1494,31 @@ class ExcitedStates(MSection):
         ''')
 
     excitation_energies = Quantity(
-        type=np.dtype(np.float64),
-        shape=['n_excited_states'],
+        type=np.float64,
+        shape=['n_energies'],
         unit='joule',
         description='''
         Excitation energies.
         ''',
         categories=[EnergyValue])
 
+    intensities = Quantity(
+        type=np.float64,
+        shape=['n_energies'],
+        description='''
+        Excitation intensities in arbitrary units.
+        ''')
+
     oscillator_strengths = Quantity(
-        type=np.dtype(np.float64),
-        shape=['n_excited_states'],
+        type=np.float64,
+        shape=['n_energies'],
         description='''
         Excited states oscillator strengths.
         ''')
 
     transition_dipole_moments = Quantity(
-        type=np.dtype(np.float64),
-        shape=['n_excited_states', 3],
+        type=np.float64,
+        shape=['n_energies', 3],
         unit='coulomb * meter',
         description='''
         Transition dipole moments.
@@ -1803,7 +1825,7 @@ class BaseCalculation(ArchiveSection):
 
     hopping_matrix = SubSection(sub_section=HoppingMatrix.m_def, repeats=True)
 
-    excited_states = SubSection(sub_section=ExcitedStates.m_def, repeats=True)
+    spectra = SubSection(sub_section=Spectra.m_def, repeats=True)
 
     greens_functions = SubSection(sub_section=GreensFunctions.m_def, repeats=True)
 
