@@ -38,14 +38,14 @@ class KMesh(MSection):
     m_def = Section(validate=False)
 
     n_points = Quantity(
-        type=int,
+        type=np.int32,
         shape=[],
         description='''
         Number of k points in the mesh (i.e. the k points used to evaluate energy_total).
         ''')
 
     grid = Quantity(
-        type=np.dtype(np.int32),
+        type=np.int32,
         shape=[3],
         description='''
         k-point grid used in notation [nx, ny, nz] in fractional coordinates.
@@ -59,7 +59,7 @@ class KMesh(MSection):
         ''')
 
     points = Quantity(
-        type=np.dtype(np.float64),
+        type=np.float64,
         shape=['n_points', 3],
         description='''
         List of all the k points in the $k$-point mesh. These are the k point used to
@@ -68,7 +68,7 @@ class KMesh(MSection):
         ''')
 
     weights = Quantity(
-        type=np.dtype(np.float64),
+        type=np.float64,
         shape=['n_points'],
         description='''
         Weights of all the k points in the $k$-point mesh. These are the weights for
@@ -222,6 +222,9 @@ class AtomParameters(MSection):
     Contains method-related information about a kind of atom identified by label. This
     allows the assignment of an atom-centered basis set or pseudopotential for different
     atoms belonging to the same kind.
+
+    Through this section we use the wording "active" mainly for defining orbital-related
+    quantities. Active refers to the relevant orbital parameters in the atom.
     '''
 
     m_def = Section(validate=False)
@@ -271,14 +274,14 @@ class AtomParameters(MSection):
         type=np.dtype(np.int32),
         shape=[],
         description='''
-        Number of valence orbitals of the atom.
+        Number of active orbitals of the atom.
         ''')
 
     orbitals = Quantity(
         type=str,
         shape=['n_orbitals'],
         description='''
-        Label of the valence orbitals of the atoms.
+        Label of the active orbitals of the atoms.
         ''')
 
     onsite_energies = Quantity(
@@ -334,6 +337,41 @@ class MoleculeParameters(MSection):
     atom_parameters = SubSection(sub_section=AtomParameters.m_def, repeats=True)
 
 
+class Photon(MSection):
+    '''
+    Section containing the details of the photon field used for spectrum calculations.
+    '''
+
+    m_def = Section(validate=False)
+
+    multipole_type = Quantity(
+        type=str,
+        description='''
+        Type used for the multipolar expansion: dipole, quadrupole, NRIXS, Raman, etc.
+        ''')
+
+    polarization = Quantity(
+        type=np.float64,
+        shape=[3],
+        description='''
+        Direction of the photon polarization in cartesian coordinates.
+        ''')
+
+    energy = Quantity(
+        type=np.float64,
+        unit='joule',
+        description='''
+        Photon energy.
+        ''')
+
+    momentum_transfer = Quantity(
+        type=np.float64,
+        shape=[3],
+        description='''
+        Momentum transfer which would be important for quadrupole or NRIXS or Raman.
+        ''')
+
+
 class GaussianBasisGroup(MSection):
     '''
     Section that describes a group of Gaussian contractions. Groups allow one to calculate
@@ -867,6 +905,43 @@ class LatticeModelHamiltonian(MSection):
     hubbard_kanamori_model = SubSection(sub_section=HubbardKanamoriModel.m_def, repeats=True)
 
 
+class FreqMesh(MSection):
+    '''
+    Contains the settings for a uniformly spaced (real) frequency-point grid (if employed).
+    '''
+
+    m_def = Section(validate=False)
+
+    type = Quantity(
+        type=str,
+        shape=[],
+        description='''
+        Grid type.
+        ''')
+
+    n_points = Quantity(
+        type=np.int32,
+        shape=[],
+        description='''
+        Number of frequency points in the mesh.
+        ''')
+
+    values = Quantity(
+        type=np.complex128,
+        shape=['n_points'],
+        unit='joule',
+        description='''
+        List of all the real+imag frequencies.
+        ''')
+
+    weights = Quantity(
+        type=np.float64,
+        shape=['n_points'],
+        description='''
+        Weights of all the frequencies.
+        ''')
+
+
 class GW(MSection):
     '''
     Section containing the various parameters that define a GW calculation.
@@ -875,7 +950,7 @@ class GW(MSection):
     m_def = Section(validate=False)
 
     type = Quantity(
-        type=MEnum(["G0W0", "scGW", "scGW0", "scG0W", "ev-scGW", "qp-scGW"]),
+        type=MEnum(["G0W0", "scGW", "scGW0", "scG0W", "ev-scGW0", "ev-scGW", "qp-scGW0", "qp-scGW"]),
         shape=[],
         description='''
         GW Hedin's self-consistency cycle:
@@ -884,80 +959,25 @@ class GW(MSection):
 
         | --------- | -------------------------------- | --------------------- |
 
-        | `"G0W0"`  | single-shot                      | -                     |
+        | `"G0W0"`  | single-shot                      | PRB 74, 035101 (2006) |
 
-        | `"scGW"`  | self-consistent GW               | PRB 88, 075105 (2013) |
+        | `"scGW"`  | self-consistent G and W               | PRB 75, 235102 (2007) |
 
         | `"scGW0"` | self-consistent G with fixed W0  | PRB 54, 8411 (1996)   |
 
         | `"scG0W"` | self-consistent W with fixed G0  | -                     |
 
-        | `"ev-scGW"`  | eigenvalues self-consistent GW   | PRB 34, 5390 (1986)   |
+        | `"ev-scGW0"`  | eigenvalues self-consistent G with fixed W0   | PRB 34, 5390 (1986)   |
 
-        | `"qp-scGW"`  | quasiparticle self-consistent GW | PRL 96, 226402 (2006) |
+        | `"ev-scGW"`  | eigenvalues self-consistent G and W   | PRB 74, 045102 (2006)   |
+
+        | `"qp-scGW0"`  | quasiparticle self-consistent G with fixed W0 | PRL 99, 115109 (2007) |
+
+        | `"qp-scGW"`  | quasiparticle self-consistent G and W | PRL 96, 226402 (2006) |
         ''')
 
-    q_grid = SubSection(sub_section=KMesh.m_def, repeats=False)
-
-    n_frequencies = Quantity(
-        type=np.dtype(np.int32),
-        shape=[],
-        description='''
-        Number of frequency points used in the calculation of the self energy.
-        ''')
-
-    frequency_values = Quantity(
-        type=np.dtype(np.float64),
-        shape=['n_frequencies'],
-        unit='joule',
-        description='''
-        Values of the frequency used in the calculation of the self energy.
-        ''')
-
-    core_treatment = Quantity(
-        type=str,
-        shape=[],
-        description='''
-        Specifies if core states are treated in the GW calculation:
-
-        | Name    | Description                                             |
-
-        | ------- | ------------------------------------------------------- |
-
-        | `"all"` | All electron calculation                                |
-
-        | `"val"` | Valence electron only calculation                       |
-
-        | `"fc"`  | Frozen-core approximation                               |
-
-        | `"xal"` | All electron treatment of the exchange self-energy only |
-        ''')
-
-    dielectric_function_treatment = Quantity(
-        type=str,
-        shape=[],
-        description='''
-        Model used to calculate the dinamically-screened dielectric function:
-
-        | Name        | Description                                    | Reference             |
-
-        | ----------- | ---------------------------------------------- | --------------------- |
-
-        | `"rpa"`     | Full frequency random-phase approximation      | -                     |
-
-        | `"ppm"`     | Godby-Needs plasmon-pole model                 | PRL 62, 1169 (1989)   |
-
-        | `"ppm_hl"`  | Hybertsen and Louie plasmon-pole model         | PRB 34, 5390 (1986)   |
-
-        | `"ppm_hl2"` | von der Linden and P. Horsh plasmon-pole model | PRB 37, 8351 (1988)   |
-
-        | `"ppm_fe"`  | Farid and Engel plasmon-pole model             | PRB 47, 15931 (1993)  |
-
-        | `"cdm"`     | Countour-deformation method                    | PRB 67, 155208 (2003) |
-        ''')
-
-    self_energy_analytical_continuation = Quantity(
-        type=MEnum(["pade", "multi-pole", "CD"]),
+    analytical_continuation = Quantity(
+        type=MEnum(["pade", "contour_deformation", "ppm_GodbyNeeds", "ppm_HybertsenLouie", "ppm_vonderLindenHorsh", "ppm_FaridEngel", "multi_pole"]),
         shape=[],
         description='''
         Analytical continuation approximations of the GW self-energy:
@@ -966,28 +986,130 @@ class GW(MSection):
 
         | -------------- | ------------------- | -------------------------------- |
 
-        | `"pade"`       | Pade's approximant  | J. Low Temp. Phys 29, 179 (1977) |
+        | `"pade"` | Pade's approximant  | J. Low Temp. Phys 29, 179 (1977) |
 
-        | `"multi-pole"` | Multi-pole fitting  | PRL 74, 1827 (1995)              |
+        | `"contour_deformation"` | Contour deformation | PRB 67, 155208 (2003) |
 
-        | `"CD"`         | Contour deformation | PRB 67, 155208 (2003)            |
+        | `"ppm_GodbyNeeds"` | Godby-Needs plasmon-pole model | PRL 62, 1169 (1989) |
+
+        | `"ppm_HybertsenLouie"` | Hybertsen and Louie plasmon-pole model | PRB 34, 5390 (1986) |
+
+        | `"ppm_vonderLindenHorsh"` | von der Linden and P. Horsh plasmon-pole model | PRB 37, 8351 (1988) |
+
+        | `"ppm_FaridEngel"` | Farid and Engel plasmon-pole model  | PRB 47, 15931 (1993) |
+
+        | `"multi_pole"` | Multi-pole fitting  | PRL 74, 1827 (1995) |
+        ''')
+
+    q_grid = SubSection(sub_section=KMesh.m_def, repeats=False)
+
+    frequency_grid = SubSection(sub_section=FreqMesh.m_def, repeats=False)
+
+    interval_qp_corrections = Quantity(
+        type=np.int32,
+        shape=[2],
+        description='''
+        Band indices (in an interval) for which the GW quasiparticle corrections are
+        calculated.
+        ''')
+
+    n_states_self_energy = Quantity(
+        type=np.int32,
+        shape=[],
+        description='''
+        Number of states used in the calculation of the GW self energy.
         ''')
 
     n_empty_states_polarizability = Quantity(
-        type=np.dtype(np.int32),
+        type=np.int32,
         shape=[],
         description='''
-        Number of empty states used to compute the polarizability P
+        Number of empty states used in the calculation of the polarizability.
         ''')
 
     n_empty_states_self_energy = Quantity(
-        type=np.dtype(np.int32),
+        type=np.int32,
         shape=[],
         description='''
-        Number of empty states to be used to calculate the correlation self energy.
+        Number of empty states used in the calculation of the GW self energy.
         ''')
 
 
+class CoreHole(MSection):
+    '''
+    Section containing the various parameters that define a core-hole calculation. It can
+    be within BSE as a "core" subsection.
+    '''
+
+    m_def = Section(validate=False)
+
+    solver = Quantity(
+        type=str,
+        description='''
+        Solver algorithm used for the core-hole spectra.
+        ''')
+
+    edge = Quantity(
+        type=MEnum([
+            "K", "L1", "L2", "L3", "L23", "M1", "M2", "M3", "M23", "M4", "M5", "M45",
+            "N1", "N2", "N3", "N23", "N4", "N5", "N45"]),
+        description='''
+        Edge to be calculated for the core-hole spectra.
+        ''')
+
+    mode = Quantity(
+        type=MEnum(["absorption", "emission"]),
+        description='''
+        Type of spectra to be calculated: absorption or emission.
+        ''')
+
+    broadening = Quantity(
+        type=np.float64,
+        unit='electron_volt',
+        description='''
+        Core-hole lifetime broadening applied to the edge spectra in full-width at half maximum.
+        ''')
+
+
+class BSE(MSection):
+    '''
+    Section containing the various parameters that define a BSE calculation.
+    '''
+
+    m_def = Section(validate=False)
+
+    n_empty_states = Quantity(
+        type=np.int32,
+        shape=[],
+        description='''
+        Number of empty states to calculate the BSE response function.
+        ''')
+
+    screening_type = Quantity(
+        type=str,
+        description='''
+        Type of treatment for the screening.
+        ''')
+
+    dielectric_infinity = Quantity(
+        type=np.int32,
+        description='''
+        Value of the static dielectric constant at infinite q. For metals, this is infinite,
+        while for insulators is finite.
+        ''')
+
+    n_empty_states_screening = Quantity(
+        type=np.int32,
+        shape=[],
+        description='''
+        Number of empty states to calculate the screening matrix.
+        ''')
+
+    k_mesh_screening = SubSection(sub_section=KMesh.m_def)
+
+    core = SubSection(sub_section=CoreHole.m_def)
+
+
 class DMFT(MSection):
     '''
     Section containing the various parameters that define a DMFT calculation
@@ -1435,6 +1557,8 @@ class Method(ArchiveSection):
 
     gw = SubSection(sub_section=GW.m_def)
 
+    bse = SubSection(sub_section=BSE.m_def)
+
     dmft = SubSection(sub_section=DMFT.m_def)
 
     tb = SubSection(sub_section=TB.m_def)
@@ -1453,5 +1577,9 @@ class Method(ArchiveSection):
 
     basis_set = SubSection(sub_section=BasisSet.m_def, repeats=True, label_quantity='type')
 
+    photon = SubSection(sub_section=Photon.m_def, repeats=True)
+
+    core_hole = SubSection(sub_section=CoreHole.m_def, repeats=True)
+
 
 m_package.__init_metainfo__()
