@@ -21,6 +21,7 @@ import typing                 # pylint: disable=unused-import
 from nomad.metainfo import (  # pylint: disable=unused-import
     MSection, MCategory, Category, Package, Quantity, Section, SubSection, SectionProxy,
     Reference, MEnum, derived)
+from nomad.datamodel.data import ArchiveSection
 
 from ..common import FastAccess
 
@@ -184,7 +185,7 @@ class Atoms(MSection):
         shape=[3, 3],
         unit='meter',
         description='''
-        Lattice vectors in cartesian coordinates of the simulation cell. The
+        Lattice vectors of the simulation cell in cartesian coordinates. The
         last (fastest) index runs over the $x,y,z$ Cartesian coordinates, and the first
         index runs over the 3 lattice vectors.
         ''')
@@ -194,8 +195,8 @@ class Atoms(MSection):
         shape=[3, 3],
         unit='1/meter',
         description='''
-        Reciprocal lattice vectors in cartesian coordinates of the simulation cell. The
-        first index runs over the $x,y,z$ Cartesian coordinates, and the second index runs
+        Reciprocal lattice vectors of the simulation cell, in cartesian coordinates and with the 2 $pi$ pre-factor.
+        The first index runs over the $x,y,z$ Cartesian coordinates, and the second index runs
         over the 3 lattice vectors.
         ''')
 
@@ -231,6 +232,31 @@ class Atoms(MSection):
         zero.
         ''')
 
+    def to_ase(self, raise_exp: bool = False):
+        '''
+        Returns an ASE Object that represents the data in this section.
+
+        Arguments:
+            raise_exp: Optional flag to raise an exception instead of return None, if
+                the ASE object could not be created.
+
+        Returns:
+            The ASE Object or None, if the ASE Object could not be created (e.g. due
+            to missing data).
+        '''
+        try:
+            from ase import Atoms
+            return Atoms(
+                symbols=self.labels,
+                positions=self.positions.m,
+                cell=self.lattice_vectors.m,
+                pbc=self.periodic
+            )
+        except Exception as e:
+            if raise_exp:
+                raise e
+            return None
+
 
 class Symmetry(MSection):
     '''
@@ -479,7 +505,7 @@ class Constraint(MSection):
         ''')
 
 
-class System(MSection):
+class System(ArchiveSection):
     '''
     Contains parameters describing a system of atomic configuration. These inclue the
     compound name, atomic positions, lattice vectors, contraints on the atoms, etc.
