@@ -25,9 +25,11 @@ from nomad.metainfo import MSection, SubSection, Section, Quantity, MEnum, Refer
 from nomad.datamodel.metainfo.common import FastAccess
 from nomad.datamodel.metainfo.workflow2 import Workflow, Link, Task
 from nomad.datamodel.metainfo.simulation.system import System, AtomsGroup
-from nomad.datamodel.metainfo.simulation.method import Method
+from nomad.datamodel.metainfo.simulation.method import (
+    Method, XCFunctional, BasisSet, GW as GWMethodology
+)
 from nomad.datamodel.metainfo.simulation.calculation import (
-    Calculation, Dos, BandStructure, BandEnergies, Density, Potential, ExcitedStates,
+    Calculation, Dos, BandStructure, BandEnergies, Density, Potential, Spectra,
     RadiusOfGyration as RadiusOfGyrationCalculation,
     RadiusOfGyrationValues as RadiusOfGyrationValuesCalculation)
 from nomad.atomutils import archive_to_universe
@@ -484,11 +486,11 @@ class SinglePointResults(SimulationWorkflowResults):
         Reference to the charge density data.
         ''')
 
-    excited_states = Quantity(
-        type=Reference(ExcitedStates),
+    spectra = Quantity(
+        type=Reference(Spectra),
         shape=['n_data'],
         description='''
-        Reference to the excited states data.
+        Reference to the spectral data.
         ''')
 
 
@@ -524,10 +526,14 @@ class SinglePoint(SimulationWorkflow):
 
         if not self.method:
             self.method = SinglePointMethod()
+
+        if not self.inputs:
             self.inputs.append(Link(name=_workflow_method_name, section=self.method))
 
         if not self.results:
             self.results = SinglePointResults()
+
+        if not self.outputs:
             self.outputs.append(Link(name=_workflow_results_name, section=self.results))
 
         if not self.method.method:
@@ -570,8 +576,8 @@ class SinglePoint(SimulationWorkflow):
         if not self.results.potential and last_calc.potential:
             self.results.potential = last_calc.potential
 
-        if not self.results.excited_states and last_calc.excited_states:
-            self.results.excited_states = last_calc.excited_states
+        if not self.results.spectra and last_calc.spectra:
+            self.results.spectra = last_calc.spectra
 
         if not self.results.calculation_result_ref:
             self.results.calculation_result_ref = last_calc
@@ -853,6 +859,9 @@ class GeometryOptimization(SerialSimulation):
                         self.results.final_force_maximum = max_force * forces.units
 
         if not self.results.final_displacement_maximum:
+            if not self._systems:
+                return
+
             def get_atoms(index):
                 system = self._systems[index]
                 atoms = Atoms(
@@ -2328,7 +2337,23 @@ class GWResults(SimulationWorkflowResults):
 
 class GWMethod(SimulationWorkflowMethod):
 
-    pass
+    gw_method_ref = Quantity(
+        type=Reference(GWMethodology),
+        description='''
+        GW methodology reference.
+        ''')
+
+    starting_point = Quantity(
+        type=Reference(XCFunctional),
+        description='''
+        Starting point (XC functional or HF) used.
+        ''')
+
+    basis_set = Quantity(
+        type=Reference(BasisSet),
+        description='''
+        Basis set used.
+        ''')
 
 
 class GW(SerialSimulation):
@@ -2355,6 +2380,111 @@ class GW(SerialSimulation):
                 self.tasks[-1].inputs.append(Link(name=_workflow_results_name, section=self.results))
 
 
+class PhotonPolarizationResults(SimulationWorkflowResults):
+
+    n_polarizations = Quantity(
+        type=np.int32,
+        description='''
+        Number of polarizations for the phonons used for the calculations.
+        ''')
+
+    spectrum_polarization = Quantity(
+        type=Reference(Spectra),
+        shape=['n_polarizations'],
+        description='''
+        Spectrum for a given polarization of the photon.
+        ''')
+
+
+class PhotonPolarizationMethod(SimulationWorkflowMethod):
+
+    pass
+
+
+class PhotonPolarization(ParallelSimulation):
+
+    method = SubSection(sub_section=PhotonPolarizationMethod)
+
+    results = SubSection(sub_section=PhotonPolarizationResults)
+
+    def normalize(self, archive: EntryArchive, logger):
+        super().normalize(archive, logger)
+
+        if not self.method:
+            self.method = PhotonPolarizationMethod()
+            if not self.inputs:
+                self.inputs.append(Link(name=_workflow_method_name, section=self.method))
+                # link method also to first task
+                if self.tasks:
+                    self.tasks[0].inputs.append(Link(name=_workflow_method_name, section=self.method))
+
+        if not self.results:
+            self.results = PhotonPolarizationResults()
+            if not self.outputs:
+                self.outputs.append(Link(name=_workflow_results_name, section=self.results))
+                # link results also to last task
+                if self.tasks:
+                    self.tasks[-1].inputs.append(Link(name=_workflow_results_name, section=self.results))
+
+
+class ParticleHoleExcitationsResults(SimulationWorkflowResults):
+
+    dos_dft = Quantity(
+        type=Reference(Dos),
+        description='''
+        DFT density of states
+        ''')
+
+    dos_gw = Quantity(
+        type=Reference(Dos),
+        description='''
+        GW density of states
+        ''')
+
+    band_structure_dft = Quantity(
+        type=Reference(BandStructure),
+        description='''
+        DFT density of states
+        ''')
+
+    band_structure_gw = Quantity(
+        type=Reference(BandStructure),
+        description='''
+        DFT density of states
+        ''')
+
+    spectra = SubSection(sub_section=PhotonPolarizationResults, repeats=True)
+
+
+class ParticleHoleExcitationsMethod(SimulationWorkflowMethod):
+
+    pass
+
+
+class ParticleHoleExcitations(SerialSimulation):
+
+    method = SubSection(sub_section=ParticleHoleExcitationsMethod)
+
+    results = SubSection(sub_section=ParticleHoleExcitationsResults)
+
+    def normalize(self, archive: EntryArchive, logger):
+        super().normalize(archive, logger)
+
+        if not self.method:
+            self.method = ParticleHoleExcitationsMethod()
+            self.inputs.append(Link(name=_workflow_method_name, section=self.method))
+            # link method also to first task
+            if self.tasks:
+                self.tasks[0].inputs.append(Link(name=_workflow_method_name, section=self.method))
+
+        if not self.results:
+            self.results = ParticleHoleExcitationsResults()
+            self.outputs.append(Link(name=_workflow_results_name, section=self.results))
+            # link results also to last task
+            if self.tasks:
+                self.tasks[-1].inputs.append(Link(name=_workflow_results_name, section=self.results))
+
+
 class EquationOfStateMethod(SimulationWorkflowMethod):
 
     energy_calculator = Quantity(
