@@ -1645,7 +1645,7 @@ class Method(MSection):
         ''',
     )
     method_name = Quantity(
-        type=MEnum(['DFT', 'Projection', 'GW', 'DMFT', 'EELS', 'XPS', config.services.unavailable_value]),
+        type=MEnum(['DFT', 'Projection', 'GW', 'DMFT', 'CoreHole', 'BSE', 'EELS', 'XPS', config.services.unavailable_value]),
         description='''
         Common name for the used method.
         ''',
