@@ -44,7 +44,6 @@ original mainfile, and vice versa.
 '''
 
 from abc import ABCMeta
-import sys
 from typing import IO, Set, Dict, Iterable, Iterator, List, Tuple, Any, NamedTuple
 from functools import lru_cache
 from pydantic import BaseModel
@@ -59,17 +58,12 @@ import io
 import json
 import yaml
 import magic
+import zipfile
 
 from nomad import config, utils, datamodel
+from nomad.config.models import BundleImportSettings, BundleExportSettings
 from nomad.archive import write_archive, read_archive, ArchiveReader
 
-# TODO this should become obsolete, once we are going beyong python 3.6. For now
-# python 3.6's zipfile does not allow to seek/tell within a file-like opened from a
-# file in a zipfile.
-if sys.version_info >= (3, 7):
-    import zipfile
-else:
-    import zipfile37 as zipfile
 
 decompress_file_extensions = ('.zip', '.tgz', '.gz', '.tar.gz', '.tar.bz2', '.tar')
 bundle_info_filename = 'bundle_info.json'
@@ -669,7 +663,7 @@ class UploadFiles(DirectoryObject, metaclass=ABCMeta):
         pass
 
     def delete(self) -> None:
-        shutil.rmtree(self.os_path)
+        shutil.rmtree(self.os_path, ignore_errors=True)
         if config.fs.prefix_size > 0:
             # If using prefix, also remove the parent directory if empty
             parent_directory = os.path.dirname(self.os_path)
@@ -680,7 +674,7 @@ class UploadFiles(DirectoryObject, metaclass=ABCMeta):
                     utils.get_logger(__name__).error(
                         'could not remove empty prefix dir', directory=parent_directory, exc_info=e)
 
-    def files_to_bundle(self, export_settings: config.BundleExportSettings) -> Iterable[FileSource]:
+    def files_to_bundle(self, export_settings: BundleExportSettings) -> Iterable[FileSource]:
         '''
         A generator of :class:`FileSource` objects, defining the files/folders to be included in an
         upload bundle when *exporting*. The arguments allows for further filtering of what to include.
@@ -692,7 +686,7 @@ class UploadFiles(DirectoryObject, metaclass=ABCMeta):
 
     @classmethod
     def files_from_bundle(
-            cls, bundle_file_source: BrowsableFileSource, import_settings: config.BundleImportSettings) -> Iterable[FileSource]:
+            cls, bundle_file_source: BrowsableFileSource, import_settings: BundleImportSettings) -> Iterable[FileSource]:
         '''
         Returns an Iterable of :class:`FileSource`, defining the files/folders to be included in an
         upload bundle when *importing*. Only the files specified by the import_settings are included.
@@ -1175,7 +1169,7 @@ class StagingUploadFiles(UploadFiles):
             hash.update(mainfile_key.encode('utf8'))
         return utils.make_websave(hash)
 
-    def files_to_bundle(self, export_settings: config.BundleExportSettings) -> Iterable[FileSource]:
+    def files_to_bundle(self, export_settings: BundleExportSettings) -> Iterable[FileSource]:
         # Defines files for upload bundles of staging uploads.
         if export_settings.include_raw_files:
             yield DiskFileSource(self.os_path, 'raw')
@@ -1184,7 +1178,7 @@ class StagingUploadFiles(UploadFiles):
 
     @classmethod
     def files_from_bundle(
-            cls, bundle_file_source: BrowsableFileSource, import_settings: config.BundleImportSettings) -> Iterable[FileSource]:
+            cls, bundle_file_source: BrowsableFileSource, import_settings: BundleImportSettings) -> Iterable[FileSource]:
         # Files to import for a staging upload
         if import_settings.include_raw_files:
             yield bundle_file_source.sub_source('raw')
@@ -1520,7 +1514,7 @@ class PublicUploadFiles(UploadFiles):
         self._raw_zip_file = self._raw_zip_file_object = None
         self._archive_msg_file = self._archive_msg_file_object = None
 
-    def files_to_bundle(self, export_settings: config.BundleExportSettings) -> Iterable[FileSource]:
+    def files_to_bundle(self, export_settings: BundleExportSettings) -> Iterable[FileSource]:
         # Defines files for upload bundles of published uploads.
         for filename in sorted(os.listdir(self.os_path)):
             if filename.startswith('raw-') and export_settings.include_raw_files:
@@ -1530,7 +1524,7 @@ class PublicUploadFiles(UploadFiles):
 
     @classmethod
     def files_from_bundle(
-            cls, bundle_file_source: BrowsableFileSource, import_settings: config.BundleImportSettings) -> Iterable[FileSource]:
+            cls, bundle_file_source: BrowsableFileSource, import_settings: BundleImportSettings) -> Iterable[FileSource]:
         for filename in bundle_file_source.directory_list(''):
             if filename.startswith('raw-') and import_settings.include_raw_files:
                 yield bundle_file_source.sub_source(filename)
