@@ -45,6 +45,8 @@ from .normalizer import Normalizer
 from .band_structure import BandStructureNormalizer
 from .workflow import WorkflowNormalizer
 from .results import ResultsNormalizer
+from .metainfo import MetainfoNormalizer
+from .workflow2 import WorkflowNormalizer as Workflow2Normalizer
 
 normalizers: Iterable[Type[Normalizer]] = [
     SystemNormalizer,
@@ -52,5 +54,7 @@ normalizers: Iterable[Type[Normalizer]] = [
     DosNormalizer,
     BandStructureNormalizer,
     WorkflowNormalizer,
-    ResultsNormalizer
+    Workflow2Normalizer,
+    ResultsNormalizer,
+    MetainfoNormalizer
 ]
