@@ -23,8 +23,8 @@ from ase import Atoms
 import numpy as np
 import json
 import re
-from matid import SymmetryAnalyzer, Classifier
-from matid.classifications import Class0D, Atom, Class1D, Material2D, Surface, Class3D
+from matid import SymmetryAnalyzer, Classifier  # pylint: disable=import-error
+from matid.classifications import Class0D, Atom, Class1D, Material2D, Surface, Class3D  # pylint: disable=import-error
 
 from nomad import atomutils, archive
 from nomad.atomutils import Formula
