@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-from typing import List, Iterable, Dict, Union, Any, Optional
+from typing import List, Iterable, Dict, Union, Any, Optional, IO
 from abc import ABCMeta, abstractmethod
 import re
 import os
@@ -28,6 +28,7 @@ from pydantic import BaseModel, Extra  # pylint: disable=unused-import
 import yaml
 import h5py
 import numpy as np
+import json
 
 from nomad import config, utils
 from nomad.datamodel import EntryArchive, EntryMetadata
@@ -319,34 +320,39 @@ class MatchingParser(Parser):
                 if sibling_is_mainfile:
                     return False
 
+        def match(value, reference):
+            if not isinstance(value, dict):
+                equal = value == reference[()]
+                return equal.all() if isinstance(equal, np.ndarray) else equal
+
+            if not hasattr(reference, 'keys'):
+                return False
+
+            matches = []
+            reference_keys = list(reference.keys())
+            for key, val in value.items():
+                if key == '__has_key':
+                    matches.append(val in reference_keys)
+                elif key == '__has_all_keys':
+                    assert isinstance(val, list)
+                    matches.append(False not in [v in reference_keys for v in val])
+                else:
+                    if key not in reference_keys:
+                        matches.append(False)
+                        continue
+
+                    matches.append(match(val, reference[key]))
+            return False not in matches
+
         if self._mainfile_contents_dict is not None:
             is_match = False
-            if mime.startswith('application/x-hdf'):
+            if mime.startswith('application/json') or mime.startswith('text/plain'):
+                try:
+                    is_match = match(self._mainfile_contents_dict, json.load(open(filename)))
+                except Exception:
+                    pass
+            elif mime.startswith('application/x-hdf'):
                 try:
-                    def match(value, reference):
-                        if not isinstance(value, dict):
-                            equal = value == reference[()]
-                            return equal.all() if isinstance(equal, np.ndarray) else equal
-
-                        if not hasattr(reference, 'keys'):
-                            return False
-
-                        matches = []
-                        reference_keys = list(reference.keys())
-                        for key, val in value.items():
-                            if key == '__has_key':
-                                matches.append(val in reference_keys)
-                            elif key == '__has_all_keys':
-                                assert isinstance(val, list)
-                                matches.append(False not in [v in reference_keys for v in val])
-                            else:
-                                if key not in reference_keys:
-                                    matches.append(False)
-                                    continue
-
-                                matches.append(match(val, reference[key]))
-                        return False not in matches
-
                     with h5py.File(filename) as f:
                         is_match = match(self._mainfile_contents_dict, f)
                 except Exception:
@@ -363,6 +369,17 @@ class MatchingParser(Parser):
         return self.name
 
 
+def to_hdf5(value: Any, f: Union[str, IO], path: str):
+    with h5py.File(f, 'a') as root:
+        segments = path.rsplit('/', 1)
+        group = root.require_group(segments[0]) if len(segments) == 2 else root
+        dataset = group.require_dataset(
+            segments[-1], shape=value.shape if hasattr(value, 'shape') else (),
+            dtype=value.dtype if hasattr(value, 'dtype') else None)
+        dataset[...] = value.magnitude if hasattr(value, 'magnitude') else value
+    return f'{f if isinstance(f, str) else os.path.basename(f.name)}#{path}'
+
+
 class MatchingParserInterface(MatchingParser):
     '''
     An interface to the NOMAD parsers.
@@ -375,6 +392,11 @@ class MatchingParserInterface(MatchingParser):
         self._parser_class_name = parser_class_name
         self._mainfile_parser = None
 
+    def new_parser_instance(self):
+        ''' Forgets the existing parser instance and forces the creation of a new one. '''
+        self._mainfile_parser = None
+        return self._mainfile_parser
+
     @property
     def mainfile_parser(self):
         if self._mainfile_parser is None:
@@ -431,6 +453,20 @@ class ArchiveParser(MatchingParser):
             mainfile_mime_re='.*',
             mainfile_name_re=r'.*(archive|metainfo)\.(json|yaml|yml)$')
 
+    def validate_defintions(self, archive, logger=None):
+        if not archive or not archive.definitions:
+            return
+        errors, warnings = archive.definitions.m_all_validate()
+        has_definition_errors = len(errors) > 0
+        if logger:
+            for error in errors:
+                logger.error('Validation error', details=error)
+            for warning in warnings:
+                logger.warn('Validation warning', details=warning)
+
+        if has_definition_errors:
+            raise Exception('Archive contains definitions that have validation errors')
+
     def parse_file(self, mainfile, f, archive, logger=None):
         try:
             if mainfile.endswith('.json'):
@@ -453,30 +489,22 @@ class ArchiveParser(MatchingParser):
 
         # ensure that definitions are parsed first to make them available for the
         # parsing itself.
-        has_definition_errors = False
         if 'definitions' in archive_data:
             archive.definitions = Package.m_from_dict(
                 archive_data['definitions'], m_context=archive.m_context)
-            errors, warnings = archive.definitions.m_all_validate()
-            has_definition_errors = len(errors) > 0
-            if logger:
-                for error in errors:
-                    logger.error('Validation error', details=error)
-                for warning in warnings:
-                    logger.warn('Validation warning', details=warning)
 
             archive.definitions.archive = archive
 
             del archive_data['definitions']
 
         archive.m_update_from_dict(archive_data)
-        if has_definition_errors:
-            raise Exception('Archive contains definitions that have validation errors')
 
     def parse(self, mainfile: str, archive: EntryArchive, logger=None, child_archives=None):
         with open(mainfile, 'rt') as f:
             self.parse_file(mainfile, f, archive, logger)
 
+        self.validate_defintions(archive, logger)
+
 
 class MissingParser(MatchingParser):
     '''
