@@ -308,7 +308,8 @@ parsers = [
     MatchingParserInterface(
         'electronicparsers.ExcitingParser',
         metadata_path=f'{prefix_electronic}/exciting/metadata.yaml',
-        mainfile_name_re=r'^.*.OUT(\.[^/]*)?$', mainfile_contents_re=(r'EXCITING.*started')
+        mainfile_name_re=r'^.*.OUT(\.[^/]*)?$',
+        mainfile_contents_re=(r'EXCITING.*started[\s\S]+?All units are atomic ')
     ),
     MatchingParserInterface(
         'electronicparsers.FHIAimsParser',
@@ -394,8 +395,7 @@ parsers = [
             r'\s+\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\**\s*'
             r'\s+\* O   R   C   A \*\s*'
             r'\s+\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\**\s*'
-            r'\s*'
-            r'\s*--- An Ab Initio, DFT and Semiempirical electronic structure package ---\s*')
+            r'\s*')
     ),
     MatchingParserInterface(
         'electronicparsers.Psi4Parser',
@@ -469,7 +469,13 @@ parsers = [
     MatchingParserInterface(
         'atomisticparsers.AsapParser',
         metadata_path=f'{prefix_atomistic}/asap/metadata.yaml',
-        mainfile_name_re=r'.*.traj$', mainfile_mime_re=r'application/octet-stream'
+        mainfile_name_re=r'.*.traj$', mainfile_mime_re=r'application/octet-stream',
+        mainfile_binary_header_re=br'AFFormatASE\-Trajectory'
+    ),
+    MatchingParserInterface(
+        'atomisticparsers.BOPfoxParser',
+        metadata_path=f'{prefix_atomistic}/bopfox/metadata.yaml',
+        mainfile_contents_re=r'\-+\s+BOPfox \(v'
     ),
     MatchingParserInterface(
         'atomisticparsers.DFTBPlusParser',
@@ -521,6 +527,11 @@ parsers = [
         metadata_path=f'{prefix_atomistic}/tinker/metadata.yaml',
         mainfile_contents_re=r'TINKER  ---  Software Tools for Molecular Design'
     ),
+    MatchingParserInterface(
+        'atomisticparsers.XTBParser',
+        metadata_path=f'{prefix_atomistic}/xtb/metadata.yaml',
+        mainfile_contents_re=r'x T B\s+\|\s+\|\s+='
+    ),
     MatchingParserInterface(
         'workflowparsers.AFLOWParser',
         metadata_path=f'{prefix_workflow}/aflow/metadata.yaml',
@@ -576,7 +587,7 @@ parsers = [
     MatchingParserInterface(
         'workflowparsers.PhonopyParser',
         metadata_path=f'{prefix_workflow}/phonopy/metadata.yaml',
-        mainfile_name_re=(r'(.*/phonopy-FHI-aims-displacement-0*1/control.in$)|(.*/phon.+yaml)')
+        mainfile_name_re=(r'(.*/phonopy-FHI-aims-displacement-0*1/control.in$)|(.*/phon[^/]+yaml)')
     ),
     MatchingParserInterface(
         'eelsdbparser.EELSDBParser',
@@ -605,6 +616,12 @@ parsers = [
             r'Program EPW.+\s*'
             r'This program is part of the open-source Quantum ESPRESSO suite')
     ),
+    MatchingParserInterface(
+        'workflowparsers.QuantumEspressoXSpectraParser',
+        metadata_path=f'{prefix_workflow}/quantum_espresso_xspectra/metadata.yaml',
+        mainfile_mime_re=r'(application/.*)|(text/.*)',
+        mainfile_contents_re=r'\s*Program XSpectra\s*'
+    ),
     MatchingParserInterface(
         'databaseparsers.OpenKIMParser',
         metadata_path=f'{prefix_database}/openkim/metadata.yaml',
@@ -631,6 +648,12 @@ parsers = [
         mainfile_binary_header_re=br'^\x89HDF',
         mainfile_contents_dict={'__has_all_keys': ['dft_input', 'DMFT_input', 'DMFT_results']}
     ),
+    MatchingParserInterface(
+        'electronicparsers.OceanParser',
+        metadata_path=f'{prefix_electronic}/ocean/metadata.yaml',
+        mainfile_mime_re=r'(application/.*)|(text/.*)',
+        mainfile_contents_dict={'__has_all_keys': ['bse', 'structure', 'screen', 'calc']}
+    ),
     MatchingParserInterface(
         'nomad.parsing.nexus.NexusParser',
         metadata_path=os.path.join(os.path.dirname(__file__), 'metadata.yaml'),
