@@ -1,20 +1,23 @@
-# Copyright 2018 Markus Scheidgen
+#
+# Copyright The NOMAD Authors.
+#
+# This file is part of NOMAD. See https://nomad-lab.eu for further info.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#   http://www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an"AS IS" BASIS,
+# distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
 
-
-import matid.symmetry.symmetryanalyzer
-import matid.utils.segfault_protect
+import matid.symmetry.symmetryanalyzer  # pylint: disable=import-error
+import matid.utils.segfault_protect  # pylint: disable=import-error
 
 
 # A patch for the segfault protection of systax (internally uses protection for spglib calls.)
