@@ -696,7 +696,7 @@ def _api_to_es_aggregation(
     es_agg = None
 
     if isinstance(agg, TermsAggregation):
-        if not quantity.aggregateable:
+        if not quantity.aggregatable:
             raise QueryValidationError(
                 'The aggregation quantity cannot be used in a terms aggregation.',
                 loc=['aggregation', name, 'terms', 'quantity'])
@@ -1220,7 +1220,7 @@ def search(
         if required.exclude:
             excludes += required.exclude
         includes = required.include
-    search = search.source(includes=includes, excludes=excludes)
+    search = search.source(includes=includes, excludes=excludes)  # pylint: disable=no-member
 
     # aggregations
     aggs = [(name, _specific_agg(agg)) for name, agg in aggregations.items()]
